Example Project
===============
A general, concurrent and extensible functional testing framework. `Read more <https://github.com/hatlonely/qas>`_.

Installing
============

.. code-block:: bash

    pip install qas

Usage
=====

.. code-block:: bash

    git clone https://github.com/hatlonely/qas.git
    cd qas
    qas -t ops/example-docs/helloworld
